@@ -38,7 +38,7 @@
 #include "bprefs.h"
 
 
-static const char RCSID[] = "$Id: backup.c,v 1.1.1.1 2003/02/04 18:01:30 rousseau Exp $";
+static const char RCSID[] = "$Id: backup.c,v 1.1.1.2 2006-09-16 09:18:23 rousseau Exp $";
 
 
 /* Local static functions */
@@ -401,7 +401,7 @@ int dbm_move_items (char *src_name, char *dest_name, GList *node) {
     }
 
     while (node) {
-        gchar *text = (gchar *)node->data;
+        gchar *text = g_strdup((gchar *)node->data);
 
         jp_logf (JP_LOG_DEBUG,
                      "dbm_move_items() - from: %s, to: %s, text: %s\n",
@@ -409,6 +409,7 @@ int dbm_move_items (char *src_name, char *dest_name, GList *node) {
                      dest_dbf_name,
                      text);
 
+        jp_charset_j2p(text, strlen (text));
         key.dptr = text;
         key.dsize = strlen (text) + 1;
 
@@ -427,6 +428,7 @@ int dbm_move_items (char *src_name, char *dest_name, GList *node) {
         /* delete it from the src dbm */
         ret = gdbm_delete (src_dbf, key);
 
+	g_free(text);
         node = node->next;
     }
 
