@@ -30,7 +30,7 @@
 #include "bprefs.h"
 
 
-static const char RCSID[] = "$Id: gui.c,v 1.1.1.1 2003/02/04 18:01:30 rousseau Exp $";
+static const char RCSID[] = "$Id: gui.c,v 1.1.1.2 2006-09-16 09:18:23 rousseau Exp $";
 
 
 /* Global variables */
@@ -318,6 +318,7 @@ int display_databases() {
     datum key, nextkey;
 
     jp_logf (JP_LOG_DEBUG, "Backup: display databases\n");
+#define CHARSET_CONVERT_BUFFER 1024
 
     /*
      * Let's make sure the CLists have been created before we go and
@@ -341,18 +342,24 @@ int display_databases() {
         /* load the active databases */
         key = gdbm_firstkey (dbf);
         if (key.dptr) {
+	    gchar *utf8_text = g_malloc(CHARSET_CONVERT_BUFFER);
             jp_logf (JP_LOG_DEBUG, "Retrieved %s from active database file\n", key.dptr);
-            gtk_clist_append (GTK_CLIST(active_clist), &key.dptr);
+	    g_strlcpy(utf8_text, key.dptr, CHARSET_CONVERT_BUFFER);
+	    jp_charset_p2j(utf8_text, CHARSET_CONVERT_BUFFER);
+	    gtk_clist_append (GTK_CLIST(active_clist), &utf8_text);
 
             while (key.dptr) {
                 nextkey = gdbm_nextkey (dbf, key);
                 if (nextkey.dptr) {
                     jp_logf (JP_LOG_DEBUG, "Retrieved %s from active database file\n", nextkey.dptr);
-                    gtk_clist_append (GTK_CLIST(active_clist), &nextkey.dptr);
+		    g_strlcpy(utf8_text, nextkey.dptr, CHARSET_CONVERT_BUFFER);
+		    jp_charset_p2j(utf8_text, CHARSET_CONVERT_BUFFER);
+		    gtk_clist_append (GTK_CLIST(active_clist), &utf8_text);
                 }
                 free (key.dptr);
                 key = nextkey;
             }
+	    g_free(utf8_text);
         }
         else {
             jp_logf (JP_LOG_GUI, "No active databases found\n");
@@ -372,18 +379,24 @@ int display_databases() {
         /* load the inactive databases */
         key = gdbm_firstkey (dbf);
         if (key.dptr) {
+	    char *utf8_text = g_malloc(CHARSET_CONVERT_BUFFER);
             jp_logf (JP_LOG_DEBUG, "Retrieved %s from inactive database file\n", key.dptr);
-            gtk_clist_append (GTK_CLIST(inactive_clist), &key.dptr);
+	    g_strlcpy(utf8_text, key.dptr, CHARSET_CONVERT_BUFFER);
+	    jp_charset_p2j(utf8_text, CHARSET_CONVERT_BUFFER);
+            gtk_clist_append (GTK_CLIST(inactive_clist), &utf8_text);
 
             while (key.dptr) {
                 nextkey = gdbm_nextkey (dbf, key);
                 if (nextkey.dptr) {
                     jp_logf (JP_LOG_DEBUG, "Retrieved %s from inactive database file\n", nextkey.dptr);
-                    gtk_clist_append (GTK_CLIST(inactive_clist), &nextkey.dptr);
+		    g_strlcpy(utf8_text, nextkey.dptr, CHARSET_CONVERT_BUFFER);
+		    jp_charset_p2j(utf8_text, CHARSET_CONVERT_BUFFER);
+                    gtk_clist_append (GTK_CLIST(inactive_clist), &utf8_text);
                 }
                 free (key.dptr);
                 key = nextkey;
             }
+	    g_free(utf8_text);
         }
         else {
             jp_logf (JP_LOG_GUI, "No inactive databases found\n");
