@@ -41,7 +41,7 @@
 #include "bprefs.h"
 
 
-static const char RCSID[] = "$Id: plugin.c,v 1.1.1.2 2004/07/20 16:30:35 rousseau Exp $";
+static const char RCSID[] = "$Id: plugin.c,v 1.1.1.3 2006-09-16 09:18:23 rousseau Exp $";
 
 
 
@@ -114,6 +114,9 @@ int plugin_sync (int sd) {
     char db_copy_name[MAX_DBNAME + 5];
     int start;
     struct DBInfo info;
+#ifdef PILOT_LINK_0_12
+        pi_buffer_t *buffer;
+#endif
     time_t ltime;
     struct tm *now;
     char arch[28];
@@ -194,7 +197,17 @@ int plugin_sync (int sd) {
     backup_get_pref (BPREF_PERSISTENT_ARCHIVE, &persistent_archive, NULL);
 
     start = 0;
+#ifdef PILOT_LINK_0_12
+    buffer = pi_buffer_new(32 * sizeof(struct DBInfo));
+
+    while (dlp_ReadDBList(sd, 0, dlpDBListRAM | dlpDBListMultiple, start, buffer) > 0) {
+        int dbIndex;
+
+        for (dbIndex = 0; dbIndex < (buffer->used / sizeof(struct DBInfo)); dbIndex++) {
+            memcpy(&info, buffer->data + (dbIndex * sizeof(struct DBInfo)), sizeof(struct DBInfo));
+#else
     while (dlp_ReadDBList (sd, 0, dlpOpenRead, start, &info) > 0) {
+#endif
         start = info.index + 1;
 
         key.dptr = info.name;
@@ -288,7 +301,11 @@ int plugin_sync (int sd) {
             jp_logf (JP_LOG_WARN, "Failed, unable to create file %s\n", full_name);
             continue;
         }
+#ifdef PILOT_LINK_0_12
+        if (pi_file_retrieve (pi_fp, sd, 0, NULL) < 0) {
+#else
         if (pi_file_retrieve (pi_fp, sd, 0) < 0) {
+#endif
             jp_logf (JP_LOG_WARN, "Failed, unable to back up database\n");
         }
         else {
@@ -307,6 +324,11 @@ int plugin_sync (int sd) {
             store_persistent_archive (main_arch, full_name, TRUE);
         }
     }
+#ifdef PILOT_LINK_0_12
+    }
+    pi_buffer_free(buffer);
+#endif
+
 
     /* close the files */
     gdbm_close (active_dbf);
